@@ -150,6 +150,12 @@ admldapBuildInfo(char* configRoot, int *errorcode);
 PR_IMPLEMENT(void)
 destroyAdmldap(AdmldapInfo info);
 
+PR_IMPLEMENT(int)
+admldapGetSSLMin(AdmldapInfo info);
+
+PR_IMPLEMENT(int)
+admldapGetSSLMax(AdmldapInfo info);
+
 PR_IMPLEMENT(char*)
 admldapGetHost(AdmldapInfo info);
 
@@ -213,6 +219,12 @@ admldapGetExpressCGITimeout(AdmldapInfo info);
 PR_IMPLEMENT(char*)
 admldapGetLdapStart(AdmldapInfo info);
 
+PR_IMPLEMENT(char*)
+admldapGetAuthPasswd(AdmldapInfo info);
+
+PR_IMPLEMENT(char*)
+admldapGetAuthDN(AdmldapInfo info);
+
 PR_IMPLEMENT(char*)
 admldapGetConfigFileName(AdmldapInfo info);
 
