@@ -63,12 +63,15 @@
 #include <time.h>
 #include <string.h>
 #include <stdlib.h>
+#include <errno.h>
 #include <ctype.h>
 #include "version.h"
 #include "admutil_pvt.h"
 #include "libadminutil/admutil-int.h"
 #include "libadminutil/distadm.h"
 #include <ssl.h>
+#include "sslproto.h"
+#include "nss.h"
 #if defined(USE_OPENLDAP)
 #include <lber.h>
 #else
@@ -1210,7 +1213,7 @@ admldapBuildInfoOnly(char* configRoot, int *errorcode)
   char           buf[MAX_LEN],
                  *name= NULL, *password=NULL;
   int            status;
-  LDAPURLDesc    *ldapInfo;
+  LDAPURLDesc    *ldapInfo = NULL;
 
   *errorcode = ADMUTIL_OP_OK;
 
@@ -1258,6 +1261,10 @@ admldapBuildInfoOnly(char* configRoot, int *errorcode)
     return NULL;
   }
 
+  /* Get the console authentication DN and password - if it is set */
+  admInfo->authDN = treeFindValueAt(admInfo->configInfo, "authdn", 0);
+  admInfo->authPasswd = treeFindValueAt(admInfo->configInfo, "authpw", 0);
+
   if (admutil_ldap_url_parse(admInfo->serverDirectoryURL, &ldapInfo, 0, &admInfo->secure)) {
     *errorcode = ADMUTIL_SYSTEM_ERR;
     destroyAdmldap((AdmldapInfo)admInfo);
@@ -1523,6 +1530,86 @@ destroyAdmldap(AdmldapInfo info)
   }
 }
 
+/*
+ * Take a version string: ssl3, tls1.2, ..., tls2.1, etc,
+ * and return the NSS version number.
+ */
+static int
+getSSLVersion(char *version)
+{
+    if( version == NULL ){
+        return 0;
+    }
+	if( !strcasecmp(version, "ssl3") ){
+        return SSL_LIBRARY_VERSION_3_0;
+    } else {
+        char *copy = strdup(version);
+        char *iter = NULL;
+        char *comp;
+        char *endp = NULL;
+        PRUint16 major, minor, ssl_version = 0;
+
+        if( strncasecmp(version,"tls",3) == 0 ){
+            char *m = copy  + 3;
+            if((comp = strtok_r(m, ".", &iter))) {
+                major = strtol(comp, &endp, 10);
+                if( major > 0 ){
+                    major = (major + 2) << 8;
+                    if (( comp = strtok_r(NULL, ".", &iter) )){
+                        minor = strtol(comp, &endp, 10);
+                        if( minor >= 0 && errno != ERANGE ){
+                            minor = (minor & 0xff);
+                            ssl_version = major + minor;
+                            if( (ssl_version & SSL_LIBRARY_VERSION_3_0) == SSL_LIBRARY_VERSION_3_0 ){
+                                ssl_version++;
+                            }
+                        }
+                    }
+                }
+            }
+        }
+        PL_strfree(copy);
+        return ssl_version;
+    }
+}
+
+PR_IMPLEMENT(int)
+admldapGetSSLMin(AdmldapInfo info)
+{
+    SSLVersionRange range;
+    AdmldapHdnlPtr admInfo = (AdmldapHdnlPtr)info;
+    int version = getSSLVersion(treeFindValueAt(admInfo->configInfo, "sslVersionMin", 0));
+
+    if(!version){
+        return SSL_LIBRARY_VERSION_TLS_1_0;
+    } else {
+        SSL_VersionRangeGetSupported(ssl_variant_stream, &range);
+        if (version < range.min){
+            version = range.min;
+        }
+        return version;
+    }
+}
+
+PR_IMPLEMENT(int)
+admldapGetSSLMax(AdmldapInfo info)
+{
+    SSLVersionRange range;
+    AdmldapHdnlPtr admInfo = (AdmldapHdnlPtr)info;
+    int version = getSSLVersion(treeFindValueAt(admInfo->configInfo, "sslVersionMax", 0));
+
+    SSL_VersionRangeGetSupported(ssl_variant_stream, &range);
+    if(!version){
+        return range.max;
+    } else {
+        SSL_VersionRangeGetSupported(ssl_variant_stream, &range);
+        if (version > range.max){
+            version = range.max;
+        }
+        return version;
+    }
+}
+
 PR_IMPLEMENT(char*)
 admldapGetHost(AdmldapInfo info)
 {
@@ -1787,6 +1874,22 @@ admldapGetLdapStart(AdmldapInfo info)
 
 }
 
+PR_IMPLEMENT(char*)
+admldapGetAuthDN(AdmldapInfo info)
+{
+  AdmldapHdnlPtr admInfo = (AdmldapHdnlPtr)info;
+
+  return admInfo->authDN;
+}
+
+PR_IMPLEMENT(char*)
+admldapGetAuthPasswd(AdmldapInfo info)
+{
+  AdmldapHdnlPtr admInfo = (AdmldapHdnlPtr)info;
+
+  return admInfo->authPasswd;
+}
+
 PR_IMPLEMENT(char*)
 admldapGetConfigFileName(AdmldapInfo info)
 {
