@@ -59,6 +59,8 @@ typedef struct _AdmldapHdnl {
   char         *sieDN;
   char         *userDN;
   char         *passwd;
+  char         *authDN;
+  char         *authPasswd;
   int          secure;
 } AdmldapHdnl;
 
