@@ -169,7 +169,14 @@ admldapGetAdmGroupUGDN(char* sieDN)
   int    dnLen = 0;
   char   *dnbuf = NULL;
 
-  dnList = ldap_explode_dn(sieDN, 0);
+  dnList = admldap_ldap_explode_dn(sieDN, 0);
+  if (!dnList) {
+    char *envvar = PR_GetEnv("ADMINUTIL_DEBUG");
+    if (envvar && (*envvar == '1')) {
+      fprintf(stderr, "Error: could not parse sieDN [%s]\n", sieDN);
+    }
+    return PL_strdup(sieDN);
+  }
   while (dnList && dnList[dnLen]) dnLen++;
 
   if (dnLen >= 5) {
@@ -178,6 +185,12 @@ admldapGetAdmGroupUGDN(char* sieDN)
               dnList[dnLen-3],
               dnList[dnLen-2],
               dnList[dnLen-1]);
+  } else {
+    char *envvar = PR_GetEnv("ADMINUTIL_DEBUG");
+    if (envvar && (*envvar == '1')) {
+      fprintf(stderr, "Error: invalid sieDN [%s]\n", sieDN);
+    }
+    dnbuf = PL_strdup(sieDN);
   }
   admutil_strsFree(dnList);
   return dnbuf;
@@ -190,13 +203,26 @@ admldapGetDomainUGDN(char* sieDN)
   int    dnLen = 0;
   char   *dnbuf = NULL;
 
-  dnList = ldap_explode_dn(sieDN, 0);
+  dnList = admldap_ldap_explode_dn(sieDN, 0);
+  if (!dnList) {
+    char *envvar = PR_GetEnv("ADMINUTIL_DEBUG");
+    if (envvar && (*envvar == '1')) {
+      fprintf(stderr, "Error: could not parse sieDN [%s]\n", sieDN);
+    }
+    return PL_strdup(sieDN);
+  }
   while (dnList && dnList[dnLen]) dnLen++;
 
   if (dnLen >= 3) {
     dnbuf = PR_smprintf("cn=UserDirectory,ou=Global Preferences,%s,%s", 
               dnList[dnLen-2],
               dnList[dnLen-1]);
+  } else {
+    char *envvar = PR_GetEnv("ADMINUTIL_DEBUG");
+    if (envvar && (*envvar == '1')) {
+      fprintf(stderr, "Error: invalid sieDN [%s]\n", sieDN);
+    }
+    dnbuf = PL_strdup(sieDN);
   }
   admutil_strsFree(dnList);
 
